@@ -166,19 +166,20 @@ GtkWidget *label_xbig(char *str) {
   return label;
 }
 
+static void
+on_label_realize(GtkWidget *widget, gpointer user_data)  {
+  /* get parent size (which is a container) */
+  gtk_widget_set_size_request(widget, widget->parent->allocation.width, -1);
+}
+
 GtkWidget *label_wrap(char *str) {
   GtkWidget *label = gtk_label_new(str);
   gtk_label_set_line_wrap_mode(GTK_LABEL(label), PANGO_WRAP_WORD);
   gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
-#ifdef USE_MAEMO
-#if MAEMO_VERSION_MAJOR >= 5
-  gtk_widget_set_size_request(label, 720, -1);
-#else
-  gtk_widget_set_size_request(label, 640, -1);
-#endif
-#else
-  gtk_widget_set_size_request(label, 350, -1);
-#endif
+
+  g_signal_connect(G_OBJECT(label), "realize",
+                   G_CALLBACK(on_label_realize), NULL);
+
   return label;
 }
 
