@@ -156,7 +156,7 @@ static void on_link_clicked(GtkHTML *html, const gchar *url,
 			   GTK_WINDOW(appdata->window),
 			   GTK_DIALOG_DESTROY_WITH_PARENT,
 			   GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, 
-			   _("Open link on external browser?"));
+			   _("Open link in external browser?"));
   gboolean yes = (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_YES);
 #else
   GtkWidget *dialog = 
