@@ -632,16 +632,27 @@ GtkWidget *cache_notes(cache_context_t *context) {
   pos_t pos = gpx_cache_pos(cache);
   if(cache->notes) pos = cache->notes->pos;
 
-  gtk_table_attach_defaults(GTK_TABLE(table), 
-	    context->notes.latw = lat_entry_new(pos.lat), 0, 1, 1, 2);
+  context->notes.latw = lat_entry_new(pos.lat);
+  context->notes.lonw = lon_entry_new(pos.lon);
+  GtkWidget *picker = 
+    preset_coordinate_picker(context->appdata, 
+			     context->notes.latw, context->notes.lonw);
+
   g_signal_connect(G_OBJECT(context->notes.latw), "focus-out-event", 
 		   G_CALLBACK(focus_out), context);
-  
-  gtk_table_attach_defaults(GTK_TABLE(table), 
-	    context->notes.lonw = lon_entry_new(pos.lon), 2, 3, 1, 2);
   g_signal_connect(G_OBJECT(context->notes.lonw), "focus-out-event", 
 		   G_CALLBACK(focus_out), context);
 
+
+  GtkWidget *ihbox = gtk_hbox_new(FALSE, 0);
+  
+  gtk_box_pack_start_defaults(GTK_BOX(ihbox), context->notes.latw);
+  gtk_box_pack_start_defaults(GTK_BOX(ihbox), context->notes.lonw);
+  gtk_box_pack_start_defaults(GTK_BOX(ihbox), picker);
+
+  gtk_table_attach_defaults(GTK_TABLE(table), 
+			    ihbox, 0, 3, 1, 2);
+
 #if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 0);  
